/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.function.impl;

import java.util.List;
import java.util.Map;

import org.tinygroup.function.Function;
import org.tinygroup.function.FunctionManager;
import org.tinygroup.function.exception.FunctionException;

/**
 * 函数管理器实现类<br>
 * 
 * TODO这个要用在prototype方式的
 * 
 * @author luoguo
 * 
 */
public class FunctionManagerImpl implements FunctionManager {

	private Map<String, List<Function<?>>> functionMap;

	public <T> T execute(String functionName, Object... parameters) {
		if (functionMap != null) {
			List<Function<?>> functionList = functionMap.get(functionName);
			if (functionList != null) {
				for (Function<?> function : functionList) {
					boolean match = false;
					try {
						match = function.isMatch(parameters);
					} catch (RuntimeException e) {
						continue;
					}
					if (match) {
						return (T) function.execute(parameters);
					}
				}
			}
		}
		throw new FunctionException("函数<" + functionName + ">不存在。");
	}


	public void setFunctionMap(Map<String, List<Function<?>>> functionMap) {
		this.functionMap = functionMap;

	}


	public Map<String, List<Function<?>>> getFunctionMap() {
		return functionMap;
	}

}
